#
# spec file for package android-udev-rules
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           android-udev-rules
Version:        20240221
Release:        2.2
Summary:        Udev rules for Android Debug Bridge
License:        GPL-3.0-or-later
Group:          Hardware/Mobile
URL:            https://github.com/M0Rf30/android-udev-rules
Source0:        https://github.com/M0Rf30/android-udev-rules/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  udev
Recommends:     android-tools
Provides:       android-tools-udev = %{version}
Obsoletes:      android-tools-udev < %{version}
BuildArch:      noarch
%sysusers_requires

%description
This package provides udev rules to facilitate the use of devices
with Android Debug Bridge (a command-line tool for communicating with
a device to e.g. install or debug apps).
The rules set adb* group ownership on /dev files and create symlinks such as
/dev/android*.

%prep
%autosetup -p1

%build
%sysusers_generate_pre android-udev.conf adbusers android-udev.conf

%install
install -D -m 0644 -t %{buildroot}%{_sysusersdir} android-udev.conf
install -D -m 0644 -t %{buildroot}%{_udevrulesdir} 51-android.rules

%pre -f adbusers.pre

%post
%udev_rules_update

%postun
%udev_rules_update

%files
%license LICENSE
%doc README.md
%{_sysusersdir}/android-udev.conf
%{_udevrulesdir}/51-android.rules

%changelog
* Fri Mar  1 2024 Jan Engelhardt <jengelh@inai.de>
- Update descriptions to point out ADB
* Fri Mar  1 2024 munix9@googlemail.com
- Update to version 20240221
  Features
  * Add Oculus Quest 2 (close #308) (#309)
  * Add Allwinner fastboot rule (#311)
  Miscellaneous Tasks
  * Quest 2 and 3 have the same IDs
* Sun Jan 14 2024 munix9@googlemail.com
- Update to version 20240114
  Bug Fixes
  * Amazon vendor typo in comments
  Features
  * Add support for Fire HD 8 2018 (#303)
  * Add Alcatel 5024L aka Alcatel 1S (#304)
  * Add support for Fire HD 8 2012 (#306)
  * Add ASUS ZenWatch 2 (#307)
* Fri Dec  8 2023 munix9@googlemail.com
- Update to version 20231207
  Bug Fixes
  * OnePlus 6T: debug mode not detected (#298) (#300)
  Features
  * Add Hisense U8G Smart TV (#301)
  * Add Google Pixel Watch 2 (#302)
  Miscellaneous Tasks
  * Use more specific adb GOTOs for XiaoMi (#299)
* Fri Nov 24 2023 munix9@googlemail.com
- Update to version 20231124
  Bug Fixes
  * Typo within README.md (#294)
  * Motorola adbfast code, also sort codes and use default drop (#297)
  Features
  * Add CI to verify rules (#291)
  Styling
  * Remove all unused labels
* Tue Nov  7 2023 munix9@googlemail.com
- Update to version 20231104
  Bug Fixes
  * Fix Spreadtrum rule (#288)
  * Fix code due to journalctl output errors (#289)
* Tue Oct 31 2023 munix9@googlemail.com
- Update to version 20231030
  Bug Fixes
  * Use up-to-date SPDX identifiers where applicable
  * Use correct Debian Archive section name
  * Don't set value while exiting script. (#267)
  * Revert an accidental early exit
  Documentation
  * Mention wiki in README.md
  Features
  * Add Meizu M6T (#262)
  * Add ASUS MeMO Pad 7 ME176C/ME176CX in DNX/Rescue mode
  * Add support for fastboot without adb
  * Add Motorola Moto Z3 Play
  * Add MediaTek Moto E22i, MT65xx/67xx (#271)
  * Add Samsung Core and general cleanup (#276)
  * Add Motorola G3, edit some other Motorola values (#277) (#277)
  * Add Samsung Galaxy A5 (#286)
  * Add 04e8:685d ODIN link used instead of fastboot by Samsung (#284)
  Miscellaneous Tasks
  * Bump copyright to 2023 and include all years with contributions
  * Use more specific adb GOTOs for Oppo and OnePlus (#272)
  * Use more specific adb GOTOs for Asus (#273)
  * Use more specific adb GOTOs for Fairphone (#274)
  * Use more specific adb GOTOs for Xiaomi (#275)
  * Use more specific adb GOTOs for ZTE (#278) (#278)
  * Use more specific adb GOTOs for Qualcom & nVidia (#279) (#279)
  * Use more specific adb GOTOs for Google (#282)
  * Use more specific adb GOTOs for HTC (#280)
  * Use more specific adb GOTOs for LG (#281)
  * Use more specific adb GOTOs for misc (#283)
  * Modify BQ device as adb+mtp, or mtp (#285)
  Refactor
  * Use GOTO next LABEL after device found (for a faster rules script). (#266)
  Styling
  * Strip trailing spaces and make comments more readable
* Thu Jun 15 2023 munix9@googlemail.com
- Update to version 20230614
  * Add support for OnePlus Nord N10 4G in USB tethering mode (#258)
  * Add Kindle Fire 10, Anbernic RG353P, Pinephone (#257)
  * Add Amazon Fire 7 tablet (#260)
  * Add Pixel 7/Pixel 7 Pro to working Tensor Pixel devices. (#255)
* Fri Mar  3 2023 munix9@googlemail.com
- Update to version 20230303
  Bug Fixes
  * Install.sh: get current user instead of root on the automatic
    install script (#239)
  * exclude several Sony and Microsoft USB controllers, VR, BT
    (#252)
  Features
  * Add Wileyfox Swift 2 Plus (#249)
  * Add Amazon Fire TV Stick Lite (3rd gen) (#251)
  Miscellaneous Tasks
  * Rewrite Polar vendor and add Polar M600 product. (#248)
* Thu Jan  5 2023 munix9@googlemail.com
- Update to version 20230104
  Features
  * Add RMX3231 - RealmeC11 2021 (#237)
  * Add support for Vivo devices (#238)
  * Add Meizu M1 E (#246)
  * Add support for Polar vendor
  Miscellaneous Tasks
  * Add OnePlus 8T PTP and MTP support (close #240) (#245)
* Sun Sep  4 2022 munix9@googlemail.com
- Update to version 20220903
  Bug Fixes
  * Avoid wrong detections of controller devices (#234)
  Features
  * Add rules for ZTE MF286* series internal modems (#231)
  * Add product ID for CDC-NCM+ADB for Tensor Pixels (#236)
  Miscellaneous Tasks
  * Install.sh: use /bin/sh interp within shebang (#232)
  * Remove commented universal rule
  * Change fast to adbfast for Pixel C (#235)
* Wed Jun 29 2022 munix9@googlemail.com
- Update to version 20220611
  added:
  * Oppo A94 5G
  * OPPO Watch fastboot mode
  * Realme 8
  * Verifone vendor
  * Yongnuo YN450M
  * ZTE Nubia series
  * ZTE Blade A5 2020
  enhancements:
  * remove install.sh dead code
  * better indentation with spaces
  * remove duplicated Samsung 6860 product id
* Tue Jan  4 2022 munix9@googlemail.com
- Update to version 20220102
  added:
  * Alcatel 1 2019 5033F
  * Android accessory mode
  * Ascom vendor
  * 5 Ascom devices
  * Asus ZenFone 2
  * Razer Phone 2 ADB mode
  * Sony Ericsson Xperia Z Ultra
  * Xiaomi Redmi Note 8T
  * ZTE P685M LTE Cat4 modem
  enhanced:
  * T & A Mobile rules
* Mon May  3 2021 munix9@googlemail.com
- Update to version 20210501
  fixed:
  * Mediatek rules typo
* Sun Apr 25 2021 munix9@googlemail.com
- Update to version 20210425
  added:
  * Microsoft Surface Duo
  * Umidigi F1
  * Iconia Tab 210
  * Fairphone 1 & 2
  fixed:
  * Exclude BIND actions from udev triggering (close #204)
- Call %%udev_rules_update in %%post/%%postun
- Remove fix-consider-bind-action.patch (fixed upstream)
* Tue Mar  9 2021 munix9@googlemail.com
- Add fix-consider-bind-action.patch - Systemd catches up with
  bind events (boo#1183058) (gh#M0Rf30/android-udev-rules#204)
* Tue Mar  2 2021 munix9@googlemail.com
- Update to version 20210302
  added:
  * Zebra TC72
  * Unitech Electronics vendor
  * Unitech Electronics EA630
  * Xperia XZ1 Compact
  * Xperia XZ2 Compact
  * Xperia 5 II
* Sun Oct  4 2020 munix9@googlemail.com
- Update to version 20201003
  added:
  * Parrot vendor
  * Tablet Idea XDS-1078
  * Castles vendor
  * Point Mobile vendor
  * Redmi 8 Pro
  * Yandex Phone
  * Nvidia SHIELD tablet new Id
  fixed:
  * Nvidia TV Shield on fastboot
  cleanup:
  * General adherence to udev rule model
  * Reducing tests on device detection and entries processing
* Thu Jul 30 2020 munix9@googlemail.com
- Update to version 20200613
  * Indentation cleanup
  * Removed duplicate entry for Qualcomm (05c6)
  * Adds support for Huawei P10 Lite to udev rules
  * Disable ADVANCE rules: needs specific product rules
  * Add Spectralink
- Update to version 20200410
  * Cleanup of entries without an action
  * Revert "Uncommented Dell idVendor line"
  * Add Sonim as vendor
  * Essential Phone PH-1 is also known as `2e17:c032`
* Tue Jul 28 2020 olaf@aepfle.de
- This package replaces android-tools-udev version 5
  add the missing Provides/Obsoletes to avoid fileconflicts
* Fri Nov  8 2019 munix9@googlemail.com
- Initial package for version 20191103
